@@ -13,7 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "dotgrammar.h"
@@ -426,7 +426,7 @@ void checkEdgeOperator(const std::string& str)
         return;
     }
 
-    qCCritical(GRAPHTHEORY_FILEFORMAT) << "Error: incoherent edge direction relation" << endl;
+    qCCritical(GRAPHTHEORY_FILEFORMAT) << "Error: incoherent edge direction relation";
 }
 
 void edgebound(const std::string& str)
